import { h } from '@stencil/core';
import { SyntaxNames } from "../../models";
import { getInputPropertyValue } from "../../utils";
export class MultiLineInput {
  constructor() {
    this.getEditorHeight = (options) => {
      const editorHeightName = options.editorHeight || 'Default';
      switch (editorHeightName) {
        case 'Large':
          return { propertyEditor: '20em', textArea: 10 };
        default:
          return { propertyEditor: '15em', textArea: 6 };
      }
    };
    this.onPropertyEditorChanged = (e) => {
      const inputElement = e.target;
      this.inputContext.inputChanged(inputElement.value, SyntaxNames.Literal);
    };
    this.onExpressionChanged = (e) => {
      this.inputContext.inputChanged(e.detail.expression, e.detail.syntax);
    };
    this.inputContext = undefined;
  }
  render() {
    var _a, _b, _c;
    const inputContext = this.inputContext;
    const inputDescriptor = inputContext.inputDescriptor;
    const fieldName = inputDescriptor.name;
    const fieldId = inputDescriptor.name;
    const displayName = inputDescriptor.displayName;
    const hint = inputDescriptor.description;
    const input = getInputPropertyValue(inputContext);
    const options = inputDescriptor.options || {};
    const editorHeight = this.getEditorHeight(options);
    const defaultValue = inputDescriptor.defaultValue;
    const value = this.getValueOrDefault((_a = input === null || input === void 0 ? void 0 : input.expression) === null || _a === void 0 ? void 0 : _a.value, defaultValue);
    const syntax = (_c = (_b = input === null || input === void 0 ? void 0 : input.expression) === null || _b === void 0 ? void 0 : _b.type) !== null && _c !== void 0 ? _c : inputDescriptor.defaultSyntax;
    return (h("elsa-input-control-switch", { label: displayName, hint: hint, syntax: syntax, expression: value, onExpressionChanged: this.onExpressionChanged }, h("textarea", { name: fieldName, id: fieldId, value: value, rows: editorHeight.textArea, onChange: this.onPropertyEditorChanged })));
  }
  getValueOrDefault(value, defaultValue) {
    var _a;
    return (_a = value !== null && value !== void 0 ? value : defaultValue) !== null && _a !== void 0 ? _a : '';
  }
  static get is() { return "elsa-multi-line-input"; }
  static get properties() {
    return {
      "inputContext": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "ActivityInputContext",
          "resolved": "ActivityInputContext",
          "references": {
            "ActivityInputContext": {
              "location": "import",
              "path": "../../services/activity-input-driver"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        }
      }
    };
  }
}
//# sourceMappingURL=multi-line.js.map
